==> jmb.cms-misc-0.2.6.tar.gz: jmb.cms-misc-0.2.6/jmb/cms/contact_form/cms/plugins.py <==
from django.utils.translation import ugettext_lazy as _
from django.shortcuts import redirect

from cms.plugin_base import CMSPluginBase
from cms.plugin_pool import plugin_pool

from jmb.core.utils.functions import import_class
from jmb.cms.contact_form.cms.models import ContactSettings
from jmb.cms.contact_form.cms.forms import ContactForm

#FIXME: sostituire middleware ForceResponse acomea.utenti con quello di jmb.core
from acomea.utenti.middleware import ForceResponse


class ContactPlugin(CMSPluginBase):
    model = ContactSettings
    name = _("Contact Form")
    module = _("Custom CMS")
    admin_preview = False

    def render(self, context, instance, placeholder):
        request = context['request']
        self.render_template = instance.form_template_name
        form_class = import_class(instance.form)
        if request.method == "POST":
            form = form_class(request.POST)
            if form.is_valid():
                form.send(instance, request=request)
                context['instance'] = instance
                self.render_template = instance.thanks_template_name
                if instance.tracking_url:
                    raise ForceResponse(redirect(instance.tracking_url))
                return context
        else:
            form = form_class()
        half = len(form.fields)/2
        context.update({
            'contact': instance,
            'form': form,
            'half':half
        })
        return context
plugin_pool.register_plugin(ContactPlugin)

==> jmb.cms-misc-0.2.7.tar.gz: jmb.cms-misc-0.2.7/jmb/cms/contact_form/cms/plugins.py <==
from django.utils.translation import ugettext_lazy as _
from django.shortcuts import redirect

from cms.plugin_base import CMSPluginBase
from cms.plugin_pool import plugin_pool

from jmb.core.utils.functions import import_class
from jmb.cms.contact_form.cms.models import ContactSettings
from jmb.cms.contact_form.cms.forms import ContactForm

#FIXME: sostituire middleware ForceResponse acomea.utenti con quello di jmb.core
#from acomea.utenti.middleware import ForceResponse
from jmb.core.force_response import ForceResponse

class ContactPlugin(CMSPluginBase):
    model = ContactSettings
    name = _("Contact Form")
    module = _("Custom CMS")
    admin_preview = False

    def render(self, context, instance, placeholder):
        request = context['request']
        self.render_template = instance.form_template_name
        form_class = import_class(instance.form)
        if request.method == "POST":
            form = form_class(request.POST)
            if form.is_valid():
                form.send(instance, request=request)
                context['instance'] = instance
                self.render_template = instance.thanks_template_name
                if instance.tracking_url:
                    raise ForceResponse(redirect(instance.tracking_url))
                return context
        else:
            form = form_class()
        half = len(form.fields)/2
        context.update({
            'contact': instance,
            'form': form,
            'half':half
        })
        return context
plugin_pool.register_plugin(ContactPlugin)
